melonProbesEpic: Dataframe containing potentially bad probes for 450K...

Description Usage Format Source Examples

Description

Dataframe containing potentially bad probes for EPIC microarray data

Usage

1

Format

A data frame with 800,000 rows and 9 variables:

Zhou_HG19

Logical Vector of CpGs that are marked TRUE in Zhou's General Masking column for HG19

Zhou_HG38

Logical Vector of CpGs that are marked TRUE in Zhou's General Masking column for HG38

Pidsley_CrossReactive

Logical Vector of CpGs that are marked TRUE if identified to be cross-reactive by Pidsley et al.

Pidsley_GeneVariant_Body

Logical Vector of CpGs that are marked TRUE if identified to have a SNP variant within the body of the probe by Pidsley et al.

Pidsley_Overlap_Gene

Logical Vector of CpGs that are marked TRUE if identified to have multiple genes mapping to the same CpG by Pidsley et al.

Pidsley_GeneVariant_Extension

Logical Vector of CpGs that are marked TRUE if identified to have a SNP in the probe single base extension identified by Pidsley et al.

PercLowVariation

Numeric Vector describing the number of times a CpG is ranked in bottom 5th percentile of variation

PercBadBc

Numeric Vector describing the number of times a CpG has a beadcount 4 in 5 of samples.

PercBadPv

Numeric Vector describing the number of times a CpG has a detection p value 0.05 in 1 of samples.

http://zwdzwd.github.io/InfiniumAnnotation

Pidsley, R., Zotenko, E., Peters, T.J. et al. Critical evaluation of the Illumina MethylationEPIC BeadChip microarray for whole-genome DNA methylation profiling. Genome Biol 17, 208 (2016) doi:10.1186/s13059-016-1066-1

Examples

1

TJGorrie/melonProbes documentation built on May 28, 2021, 1:45 p.m.