Description Usage Format Source Examples
Dataframe containing potentially bad probes for EPIC microarray data
1 |
A data frame with 800,000 rows and 9 variables:
Logical Vector of CpGs that are marked TRUE in Zhou's General Masking column for HG19
Logical Vector of CpGs that are marked TRUE in Zhou's General Masking column for HG38
Logical Vector of CpGs that are marked TRUE if identified to be cross-reactive by Pidsley et al.
Logical Vector of CpGs that are marked TRUE if identified to have a SNP variant within the body of the probe by Pidsley et al.
Logical Vector of CpGs that are marked TRUE if identified to have multiple genes mapping to the same CpG by Pidsley et al.
Logical Vector of CpGs that are marked TRUE if identified to have a SNP in the probe single base extension identified by Pidsley et al.
Numeric Vector describing the number of times a CpG is ranked in bottom 5th percentile of variation
Numeric Vector describing the number of times a CpG has a beadcount 4 in 5 of samples.
Numeric Vector describing the number of times a CpG has a detection p value 0.05 in 1 of samples.
http://zwdzwd.github.io/InfiniumAnnotation
Pidsley, R., Zotenko, E., Peters, T.J. et al. Critical evaluation of the Illumina MethylationEPIC BeadChip microarray for whole-genome DNA methylation profiling. Genome Biol 17, 208 (2016) doi:10.1186/s13059-016-1066-1
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.